searchData={"items":[{"type":"module","title":"Hydrex","doc":"Hydrex provides automatic hydration of virtual fields in your Ecto models.\nBy deriving the `Hydrex.Hydratable` protocol and defining resolver functions for your virtual fields,\nyou can easily populate these fields when querying your models.\n\nTo use Hydrex, define virtual fields in your Ecto schema and implement resolver functions with matching names.\nThen, derive your schema with `Hydrex.Hydratable`.\n\nUse `Hydrex.Hydratable.Utils.maybe_hydrate/2` to control hydration when fetching records.","ref":"Hydrex.html"},{"type":"module","title":"Examples - Hydrex","doc":"Here's how you can use Hydrex to hydrate virtual fields in your Ecto schemas:\n\n    defmodule MyApp.Url do\n      use Ecto.Schema\n\n      @derive {Hydrex.Hydratable, []}\n      schema \"urls\" do\n        field :link, :string\n        field :title, :string\n        field :is_safe, :boolean, virtual: true\n      end\n\n      def is_safe(url) do\n        String.starts_with?(url.link, \"https://\")\n      end\n    end\n\nWhen querying your models, you can choose to hydrate the virtual fields:\n\n    import Hydrex.Hydratable.Utils, only: [maybe_hydrate: 2]\n    Repo.all(MyApp.Url) |> maybe_hydrate(hydrate: true)\n    # or\n    Repo.all(MyApp.Url) |> maybe_hydrate(true)\n\n\nSee the documentation for installation and usage details.","ref":"Hydrex.html#module-examples"},{"type":"protocol","title":"Hydrex.Hydratable","doc":"A protocol for hydrating Ecto structs with virtual fields.","ref":"Hydrex.Hydratable.html"},{"type":"function","title":"Hydrex.Hydratable.hydrate/2","doc":"Hydrates an Ecto struct or a list of structs.","ref":"Hydrex.Hydratable.html#hydrate/2"},{"type":"function","title":"Parameters - Hydrex.Hydratable.hydrate/2","doc":"- `data`: The Ecto struct or a list of structs to hydrate.\n- `virtual_fields`: A list of virtual fields to hydrate. If empty or omitted, all virtual fields will be hydrated.","ref":"Hydrex.Hydratable.html#hydrate/2-parameters"},{"type":"function","title":"Examples - Hydrex.Hydratable.hydrate/2","doc":"iex> defmodule User do\n    ...>   use Ecto.Schema\n    ...>   embedded_schema do\n    ...>     field :name, :string\n    ...>     field :age, :integer\n    ...>     field :greeting, :string, virtual: true\n    ...>   end\n    ...>   def greeting(%User{name: name}), do: \"Hello, #{name}!\"\n    ...> end\n    iex> user = %User{name: \"Alice\", age: 30}\n    iex> Hydrex.Hydratable.hydrate(user, [:greeting])\n    # or `Hydrex.Hydratable.hydrate(user, [])` in order to hydrate all virtual fields\n    # or simply: `Hydrex.Hydratable.hydrate(user)`\n    %User{name: \"Alice\", age: 30, greeting: \"Hello, Alice!\"}\n\n    iex> users = [%User{name: \"Bob\"}, %User{name: \"Carol\"}]\n    iex> Hydrex.Hydratable.hydrate(users, [:greeting])\n    [\n      %User{name: \"Bob\", age: nil, greeting: \"Hello, Bob!\"},\n      %User{name: \"Carol\", age: nil, greeting: \"Hello, Carol!\"}\n    ]","ref":"Hydrex.Hydratable.html#hydrate/2-examples"},{"type":"type","title":"Hydrex.Hydratable.t/0","doc":"All the types that implement this protocol.","ref":"Hydrex.Hydratable.html#t:t/0"},{"type":"module","title":"Hydrex.Hydratable.Utils","doc":"Utility functions for hydrating Ecto structs with virtual fields.","ref":"Hydrex.Hydratable.Utils.html"},{"type":"function","title":"Hydrex.Hydratable.Utils.maybe_hydrate/2","doc":"Conditionally hydrates the given data.\n\n# Parameters\n- `data`: The Ecto struct or a list of structs to hydrate.\n- `opts`: Options to control hydration. If `true`, all virtual fields will be hydrated.\n  If `false`, no virtual fields will be hydrated.\n  If a keyword list is provided, hydration will occur if `:hydrate` is `true`\n  or a list of virtual fields must be provided.\n\n# Examples\n\n    iex> import Hydrex.Hydratable.Utils, only: [maybe_hydrate: 2]\n    iex> my_url = %MyApp.Url{link: \"https://example.com\"}\n    iex> maybe_hydrate(my_url, true)\n    iex> maybe_hydrate(my_url, [hydrate: true])\n    iex> maybe_hydrate(my_url, [hydrate: [:is_safe]])","ref":"Hydrex.Hydratable.Utils.html#maybe_hydrate/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}